import { select, 
        csv, 
        scaleTime,
        scaleLinear,
        extent, 
        axisLeft,
       	axisBottom,
        area,
        curveBasis,
        max,
        format,
       } from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data =>{
  const xValue = d => d.year;
  const yValue = d => d.population;
  const circleRadius = 6;
  const xAxisLabel = 'Year';
  const yAxisLabel = 'Population';
  const plotTitle = 'Top World Poulation'
  const margin = {top:55, right:40, left:100, bottom:70};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain([0, max(data, yValue)])
  	.range([innerHeight, 0])
  	.nice();
    
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`)
  
  const yAxisTickFormat = number => format('.1s')(number)
  	.replace('G', 'B')
  
  const xAxis = axisBottom(xScale)
  	.ticks(6)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
    
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10)
  	.tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -60)
  	.attr('x', -innerHeight/2)
  	.attr('text-anchor','middle')
  	.attr('fill', 'black')
  	.attr('transform', `rotate(-90)`)
    .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.selectAll('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 60)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
    .text(xAxisLabel);
  
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', areaGenerator(data))
    
	// g.selectAll('circle').data(data)
	// .enter()
	// .append('circle')
	// .attr('cy', d => yScale(yValue(d)))
	// .attr('cx', d => xScale(xValue(d)))
	// .attr('r', circleRadius);
  
  svg.append('text')
  	.attr('class', 'title-label')
  	.attr('y', 40)
  	.attr('x', width/2)
    .text(plotTitle)
}
csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv')
  .then(data => {
  	data.forEach(d => {
      d.population = +d.population;
      d.year = new Date(d.year);
  
    })
  	render(data);
});